/*
 * board/renesas/koelsch/qos.c
 *     This file is koelsch QoS setting.
 *
 * Copyright (C) 2013-2014 Renesas Electronics Corporation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include <autoconf.h>
#include <hermit.h>
#include <htypes.h>
#include "r8a7791.h"

#define writel(a,b)	write32(b,a)

/* QoS version 0.240 for ES1 and version 0.320 for ES2 */

enum {
	DBSC3_00, DBSC3_01, DBSC3_02, DBSC3_03, DBSC3_04,
	DBSC3_05, DBSC3_06, DBSC3_07, DBSC3_08, DBSC3_09,
	DBSC3_10, DBSC3_11, DBSC3_12, DBSC3_13, DBSC3_14,
	DBSC3_15,
	DBSC3_NR,
};

#if 0
static u32 dbsc3_0_r_qos_addr[DBSC3_NR] = {
	[DBSC3_00] = DBSC3_0_QOS_R0_BASE,
	[DBSC3_01] = DBSC3_0_QOS_R1_BASE,
	[DBSC3_02] = DBSC3_0_QOS_R2_BASE,
	[DBSC3_03] = DBSC3_0_QOS_R3_BASE,
	[DBSC3_04] = DBSC3_0_QOS_R4_BASE,
	[DBSC3_05] = DBSC3_0_QOS_R5_BASE,
	[DBSC3_06] = DBSC3_0_QOS_R6_BASE,
	[DBSC3_07] = DBSC3_0_QOS_R7_BASE,
	[DBSC3_08] = DBSC3_0_QOS_R8_BASE,
	[DBSC3_09] = DBSC3_0_QOS_R9_BASE,
	[DBSC3_10] = DBSC3_0_QOS_R10_BASE,
	[DBSC3_11] = DBSC3_0_QOS_R11_BASE,
	[DBSC3_12] = DBSC3_0_QOS_R12_BASE,
	[DBSC3_13] = DBSC3_0_QOS_R13_BASE,
	[DBSC3_14] = DBSC3_0_QOS_R14_BASE,
	[DBSC3_15] = DBSC3_0_QOS_R15_BASE,
};

static u32 dbsc3_0_w_qos_addr[DBSC3_NR] = {
	[DBSC3_00] = DBSC3_0_QOS_W0_BASE,
	[DBSC3_01] = DBSC3_0_QOS_W1_BASE,
	[DBSC3_02] = DBSC3_0_QOS_W2_BASE,
	[DBSC3_03] = DBSC3_0_QOS_W3_BASE,
	[DBSC3_04] = DBSC3_0_QOS_W4_BASE,
	[DBSC3_05] = DBSC3_0_QOS_W5_BASE,
	[DBSC3_06] = DBSC3_0_QOS_W6_BASE,
	[DBSC3_07] = DBSC3_0_QOS_W7_BASE,
	[DBSC3_08] = DBSC3_0_QOS_W8_BASE,
	[DBSC3_09] = DBSC3_0_QOS_W9_BASE,
	[DBSC3_10] = DBSC3_0_QOS_W10_BASE,
	[DBSC3_11] = DBSC3_0_QOS_W11_BASE,
	[DBSC3_12] = DBSC3_0_QOS_W12_BASE,
	[DBSC3_13] = DBSC3_0_QOS_W13_BASE,
	[DBSC3_14] = DBSC3_0_QOS_W14_BASE,
	[DBSC3_15] = DBSC3_0_QOS_W15_BASE,
};

static u32 dbsc3_1_r_qos_addr[DBSC3_NR] = {
	[DBSC3_00] = DBSC3_1_QOS_R0_BASE,
	[DBSC3_01] = DBSC3_1_QOS_R1_BASE,
	[DBSC3_02] = DBSC3_1_QOS_R2_BASE,
	[DBSC3_03] = DBSC3_1_QOS_R3_BASE,
	[DBSC3_04] = DBSC3_1_QOS_R4_BASE,
	[DBSC3_05] = DBSC3_1_QOS_R5_BASE,
	[DBSC3_06] = DBSC3_1_QOS_R6_BASE,
	[DBSC3_07] = DBSC3_1_QOS_R7_BASE,
	[DBSC3_08] = DBSC3_1_QOS_R8_BASE,
	[DBSC3_09] = DBSC3_1_QOS_R9_BASE,
	[DBSC3_10] = DBSC3_1_QOS_R10_BASE,
	[DBSC3_11] = DBSC3_1_QOS_R11_BASE,
	[DBSC3_12] = DBSC3_1_QOS_R12_BASE,
	[DBSC3_13] = DBSC3_1_QOS_R13_BASE,
	[DBSC3_14] = DBSC3_1_QOS_R14_BASE,
	[DBSC3_15] = DBSC3_1_QOS_R15_BASE,
};

static u32 dbsc3_1_w_qos_addr[DBSC3_NR] = {
	[DBSC3_00] = DBSC3_1_QOS_W0_BASE,
	[DBSC3_01] = DBSC3_1_QOS_W1_BASE,
	[DBSC3_02] = DBSC3_1_QOS_W2_BASE,
	[DBSC3_03] = DBSC3_1_QOS_W3_BASE,
	[DBSC3_04] = DBSC3_1_QOS_W4_BASE,
	[DBSC3_05] = DBSC3_1_QOS_W5_BASE,
	[DBSC3_06] = DBSC3_1_QOS_W6_BASE,
	[DBSC3_07] = DBSC3_1_QOS_W7_BASE,
	[DBSC3_08] = DBSC3_1_QOS_W8_BASE,
	[DBSC3_09] = DBSC3_1_QOS_W9_BASE,
	[DBSC3_10] = DBSC3_1_QOS_W10_BASE,
	[DBSC3_11] = DBSC3_1_QOS_W11_BASE,
	[DBSC3_12] = DBSC3_1_QOS_W12_BASE,
	[DBSC3_13] = DBSC3_1_QOS_W13_BASE,
	[DBSC3_14] = DBSC3_1_QOS_W14_BASE,
	[DBSC3_15] = DBSC3_1_QOS_W15_BASE,
};
#endif

/* QoS version 0.320 for ES2 */

void __init qos_dbsc_init_es2(void)
{
	/* DBSC -QoS */
	/* DBSC0 - Read */
	writel(0x00000002, 0xE6791000);
	writel(0x00002096, 0xE6791004);
	writel(0x00002064, 0xE6791008);
	writel(0x00002032, 0xE679100C);
	writel(0x00001FB0, 0xE6791010);
	writel(0x00000001, 0xE6791014);
	writel(0x00002078, 0xE6791018);
	writel(0x0000204B, 0xE679101C);
	writel(0x0000201E, 0xE6791020);
	writel(0x00000001, 0xE6791028);
	writel(0x00000002, 0xE6791100);
	writel(0x00002096, 0xE6791104);
	writel(0x00002064, 0xE6791108);
	writel(0x00002032, 0xE679110C);
	writel(0x00001FB0, 0xE6791110);
	writel(0x00000001, 0xE6791114);
	writel(0x00002078, 0xE6791118);
	writel(0x0000204B, 0xE679111C);
	writel(0x0000201E, 0xE6791120);
	writel(0x00000001, 0xE6791128);
	writel(0x00000002, 0xE6791200);
	writel(0x00002096, 0xE6791204);
	writel(0x00002064, 0xE6791208);
	writel(0x00002032, 0xE679120C);
	writel(0x00001FB0, 0xE6791210);
	writel(0x00000001, 0xE6791214);
	writel(0x00002078, 0xE6791218);
	writel(0x0000204B, 0xE679121C);
	writel(0x0000201E, 0xE6791220);
	writel(0x00000001, 0xE6791228);
	writel(0x00000002, 0xE6791300);
	writel(0x00002096, 0xE6791304);
	writel(0x00002064, 0xE6791308);
	writel(0x00002032, 0xE679130C);
	writel(0x00001FB0, 0xE6791310);
	writel(0x00000001, 0xE6791314);
	writel(0x00002078, 0xE6791318);
	writel(0x0000204B, 0xE679131C);
	writel(0x0000201E, 0xE6791320);
	writel(0x00000001, 0xE6791328);
	writel(0x00000002, 0xE6791400);
	writel(0x00002096, 0xE6791404);
	writel(0x00002064, 0xE6791408);
	writel(0x00002032, 0xE679140C);
	writel(0x00001FB0, 0xE6791410);
	writel(0x00000001, 0xE6791414);
	writel(0x00002078, 0xE6791418);
	writel(0x0000204B, 0xE679141C);
	writel(0x0000201E, 0xE6791420);
	writel(0x00000001, 0xE6791428);
	writel(0x00000002, 0xE6791500);
	writel(0x00002096, 0xE6791504);
	writel(0x00002064, 0xE6791508);
	writel(0x00002032, 0xE679150C);
	writel(0x00001FB0, 0xE6791510);
	writel(0x00000001, 0xE6791514);
	writel(0x00002078, 0xE6791518);
	writel(0x0000204B, 0xE679151C);
	writel(0x0000201E, 0xE6791520);
	writel(0x00000001, 0xE6791528);
	writel(0x00000002, 0xE6791600);
	writel(0x00002096, 0xE6791604);
	writel(0x00002064, 0xE6791608);
	writel(0x00002032, 0xE679160C);
	writel(0x00001FB0, 0xE6791610);
	writel(0x00000001, 0xE6791614);
	writel(0x00002078, 0xE6791618);
	writel(0x0000204B, 0xE679161C);
	writel(0x0000201E, 0xE6791620);
	writel(0x00000001, 0xE6791628);
	writel(0x00000002, 0xE6791700);
	writel(0x00002096, 0xE6791704);
	writel(0x00002064, 0xE6791708);
	writel(0x00002032, 0xE679170C);
	writel(0x00001FB0, 0xE6791710);
	writel(0x00000001, 0xE6791714);
	writel(0x00002078, 0xE6791718);
	writel(0x0000204B, 0xE679171C);
	writel(0x0000201E, 0xE6791720);
	writel(0x00000001, 0xE6791728);
	writel(0x00000002, 0xE6791800);
	writel(0x00002096, 0xE6791804);
	writel(0x00002064, 0xE6791808);
	writel(0x00002032, 0xE679180C);
	writel(0x00001FB0, 0xE6791810);
	writel(0x00000001, 0xE6791814);
	writel(0x00002078, 0xE6791818);
	writel(0x0000204B, 0xE679181C);
	writel(0x0000201E, 0xE6791820);
	writel(0x00000001, 0xE6791828);
	writel(0x00000002, 0xE6791900);
	writel(0x00002096, 0xE6791904);
	writel(0x00002064, 0xE6791908);
	writel(0x00002032, 0xE679190C);
	writel(0x00001FB0, 0xE6791910);
	writel(0x00000001, 0xE6791914);
	writel(0x00002078, 0xE6791918);
	writel(0x0000204B, 0xE679191C);
	writel(0x0000201E, 0xE6791920);
	writel(0x00000001, 0xE6791928);
	writel(0x00000002, 0xE6791A00);
	writel(0x00002096, 0xE6791A04);
	writel(0x00002064, 0xE6791A08);
	writel(0x00002032, 0xE6791A0C);
	writel(0x00001FB0, 0xE6791A10);
	writel(0x00000001, 0xE6791A14);
	writel(0x00002078, 0xE6791A18);
	writel(0x0000204B, 0xE6791A1C);
	writel(0x0000201E, 0xE6791A20);
	writel(0x00000001, 0xE6791A28);
	writel(0x00000002, 0xE6791B00);
	writel(0x00002096, 0xE6791B04);
	writel(0x00002064, 0xE6791B08);
	writel(0x00002032, 0xE6791B0C);
	writel(0x00001FB0, 0xE6791B10);
	writel(0x00000001, 0xE6791B14);
	writel(0x00002078, 0xE6791B18);
	writel(0x0000204B, 0xE6791B1C);
	writel(0x0000201E, 0xE6791B20);
	writel(0x00000001, 0xE6791B28);
	writel(0x00000002, 0xE6791C00);
	writel(0x00002096, 0xE6791C04);
	writel(0x00002064, 0xE6791C08);
	writel(0x00002032, 0xE6791C0C);
	writel(0x00001FB0, 0xE6791C10);
	writel(0x00000001, 0xE6791C14);
	writel(0x00002078, 0xE6791C18);
	writel(0x0000204B, 0xE6791C1C);
	writel(0x0000201E, 0xE6791C20);
	writel(0x00000001, 0xE6791C28);
	writel(0x00000002, 0xE6791D00);
	writel(0x00002096, 0xE6791D04);
	writel(0x00002064, 0xE6791D08);
	writel(0x00002032, 0xE6791D0C);
	writel(0x00001FB0, 0xE6791D10);
	writel(0x00000001, 0xE6791D14);
	writel(0x00002078, 0xE6791D18);
	writel(0x0000204B, 0xE6791D1C);
	writel(0x0000201E, 0xE6791D20);
	writel(0x00000001, 0xE6791D28);
	writel(0x00000002, 0xE6791E00);
	writel(0x00002096, 0xE6791E04);
	writel(0x00002064, 0xE6791E08);
	writel(0x00002032, 0xE6791E0C);
	writel(0x00001FB0, 0xE6791E10);
	writel(0x00000001, 0xE6791E14);
	writel(0x00002078, 0xE6791E18);
	writel(0x0000204B, 0xE6791E1C);
	writel(0x0000201E, 0xE6791E20);
	writel(0x00000001, 0xE6791E28);
	writel(0x00000002, 0xE6791F00);
	writel(0x00002096, 0xE6791F04);
	writel(0x00002064, 0xE6791F08);
	writel(0x00002032, 0xE6791F0C);
	writel(0x00001FB0, 0xE6791F10);
	writel(0x00000001, 0xE6791F14);
	writel(0x00002078, 0xE6791F18);
	writel(0x0000204B, 0xE6791F1C);
	writel(0x0000201E, 0xE6791F20);
	writel(0x00000001, 0xE6791F28);

	/* DBSC0 - Write */
	writel(0x00000002, 0xE6792000);
	writel(0x00002096, 0xE6792004);
	writel(0x00002064, 0xE6792008);
	writel(0x00002050, 0xE679200C);
	writel(0x0000203A, 0xE6792010);
	writel(0x00000001, 0xE6792014);
	writel(0x00002078, 0xE6792018);
	writel(0x0000204B, 0xE679201C);
	writel(0x0000203C, 0xE6792020);
	writel(0x00000001, 0xE6792028);
	writel(0x00000002, 0xE6792100);
	writel(0x00002096, 0xE6792104);
	writel(0x00002064, 0xE6792108);
	writel(0x00002050, 0xE679210C);
	writel(0x0000203A, 0xE6792110);
	writel(0x00000001, 0xE6792114);
	writel(0x00002078, 0xE6792118);
	writel(0x0000204B, 0xE679211C);
	writel(0x0000203C, 0xE6792120);
	writel(0x00000001, 0xE6792128);
	writel(0x00000002, 0xE6792200);
	writel(0x00002096, 0xE6792204);
	writel(0x00002064, 0xE6792208);
	writel(0x00002050, 0xE679220C);
	writel(0x0000203A, 0xE6792210);
	writel(0x00000001, 0xE6792214);
	writel(0x00002078, 0xE6792218);
	writel(0x0000204B, 0xE679221C);
	writel(0x0000203C, 0xE6792220);
	writel(0x00000001, 0xE6792228);
	writel(0x00000002, 0xE6792300);
	writel(0x00002096, 0xE6792304);
	writel(0x00002064, 0xE6792308);
	writel(0x00002050, 0xE679230C);
	writel(0x0000203A, 0xE6792310);
	writel(0x00000001, 0xE6792314);
	writel(0x00002078, 0xE6792318);
	writel(0x0000204B, 0xE679231C);
	writel(0x0000203C, 0xE6792320);
	writel(0x00000001, 0xE6792328);
	writel(0x00000002, 0xE6792400);
	writel(0x00002096, 0xE6792404);
	writel(0x00002064, 0xE6792408);
	writel(0x00002050, 0xE679240C);
	writel(0x0000203A, 0xE6792410);
	writel(0x00000001, 0xE6792414);
	writel(0x00002078, 0xE6792418);
	writel(0x0000204B, 0xE679241C);
	writel(0x0000203C, 0xE6792420);
	writel(0x00000001, 0xE6792428);
	writel(0x00000002, 0xE6792500);
	writel(0x00002096, 0xE6792504);
	writel(0x00002064, 0xE6792508);
	writel(0x00002050, 0xE679250C);
	writel(0x0000203A, 0xE6792510);
	writel(0x00000001, 0xE6792514);
	writel(0x00002078, 0xE6792518);
	writel(0x0000204B, 0xE679251C);
	writel(0x0000203C, 0xE6792520);
	writel(0x00000001, 0xE6792528);
	writel(0x00000002, 0xE6792600);
	writel(0x00002096, 0xE6792604);
	writel(0x00002064, 0xE6792608);
	writel(0x00002050, 0xE679260C);
	writel(0x0000203A, 0xE6792610);
	writel(0x00000001, 0xE6792614);
	writel(0x00002078, 0xE6792618);
	writel(0x0000204B, 0xE679261C);
	writel(0x0000203C, 0xE6792620);
	writel(0x00000001, 0xE6792628);
	writel(0x00000002, 0xE6792700);
	writel(0x00002096, 0xE6792704);
	writel(0x00002064, 0xE6792708);
	writel(0x00002050, 0xE679270C);
	writel(0x0000203A, 0xE6792710);
	writel(0x00000001, 0xE6792714);
	writel(0x00002078, 0xE6792718);
	writel(0x0000204B, 0xE679271C);
	writel(0x0000203C, 0xE6792720);
	writel(0x00000001, 0xE6792728);
	writel(0x00000002, 0xE6792800);
	writel(0x00002096, 0xE6792804);
	writel(0x00002064, 0xE6792808);
	writel(0x00002050, 0xE679280C);
	writel(0x0000203A, 0xE6792810);
	writel(0x00000001, 0xE6792814);
	writel(0x00002078, 0xE6792818);
	writel(0x0000204B, 0xE679281C);
	writel(0x0000203C, 0xE6792820);
	writel(0x00000001, 0xE6792828);
	writel(0x00000002, 0xE6792900);
	writel(0x00002096, 0xE6792904);
	writel(0x00002064, 0xE6792908);
	writel(0x00002050, 0xE679290C);
	writel(0x0000203A, 0xE6792910);
	writel(0x00000001, 0xE6792914);
	writel(0x00002078, 0xE6792918);
	writel(0x0000204B, 0xE679291C);
	writel(0x0000203C, 0xE6792920);
	writel(0x00000001, 0xE6792928);
	writel(0x00000002, 0xE6792A00);
	writel(0x00002096, 0xE6792A04);
	writel(0x00002064, 0xE6792A08);
	writel(0x00002050, 0xE6792A0C);
	writel(0x0000203A, 0xE6792A10);
	writel(0x00000001, 0xE6792A14);
	writel(0x00002078, 0xE6792A18);
	writel(0x0000204B, 0xE6792A1C);
	writel(0x0000203C, 0xE6792A20);
	writel(0x00000001, 0xE6792A28);
	writel(0x00000002, 0xE6792B00);
	writel(0x00002096, 0xE6792B04);
	writel(0x00002064, 0xE6792B08);
	writel(0x00002050, 0xE6792B0C);
	writel(0x0000203A, 0xE6792B10);
	writel(0x00000001, 0xE6792B14);
	writel(0x00002078, 0xE6792B18);
	writel(0x0000204B, 0xE6792B1C);
	writel(0x0000203C, 0xE6792B20);
	writel(0x00000001, 0xE6792B28);
	writel(0x00000002, 0xE6792C00);
	writel(0x00002096, 0xE6792C04);
	writel(0x00002064, 0xE6792C08);
	writel(0x00002050, 0xE6792C0C);
	writel(0x0000203A, 0xE6792C10);
	writel(0x00000001, 0xE6792C14);
	writel(0x00002078, 0xE6792C18);
	writel(0x0000204B, 0xE6792C1C);
	writel(0x0000203C, 0xE6792C20);
	writel(0x00000001, 0xE6792C28);
	writel(0x00000002, 0xE6792D00);
	writel(0x00002096, 0xE6792D04);
	writel(0x00002064, 0xE6792D08);
	writel(0x00002050, 0xE6792D0C);
	writel(0x0000203A, 0xE6792D10);
	writel(0x00000001, 0xE6792D14);
	writel(0x00002078, 0xE6792D18);
	writel(0x0000204B, 0xE6792D1C);
	writel(0x0000203C, 0xE6792D20);
	writel(0x00000001, 0xE6792D28);
	writel(0x00000002, 0xE6792E00);
	writel(0x00002096, 0xE6792E04);
	writel(0x00002064, 0xE6792E08);
	writel(0x00002050, 0xE6792E0C);
	writel(0x0000203A, 0xE6792E10);
	writel(0x00000001, 0xE6792E14);
	writel(0x00002078, 0xE6792E18);
	writel(0x0000204B, 0xE6792E1C);
	writel(0x0000203C, 0xE6792E20);
	writel(0x00000001, 0xE6792E28);
	writel(0x00000002, 0xE6792F00);
	writel(0x00002096, 0xE6792F04);
	writel(0x00002064, 0xE6792F08);
	writel(0x00002050, 0xE6792F0C);
	writel(0x0000203A, 0xE6792F10);
	writel(0x00000001, 0xE6792F14);
	writel(0x00002078, 0xE6792F18);
	writel(0x0000204B, 0xE6792F1C);
	writel(0x0000203C, 0xE6792F20);
	writel(0x00000001, 0xE6792F28);

	/* DBSC1 - Read */
	writel(0x00000002, 0xE67A1000);
	writel(0x00002096, 0xE67A1004);
	writel(0x00002064, 0xE67A1008);
	writel(0x00002032, 0xE67A100C);
	writel(0x00001FB0, 0xE67A1010);
	writel(0x00000001, 0xE67A1014);
	writel(0x00002078, 0xE67A1018);
	writel(0x0000204B, 0xE67A101C);
	writel(0x0000201E, 0xE67A1020);
	writel(0x00000001, 0xE67A1028);
	writel(0x00000002, 0xE67A1100);
	writel(0x00002096, 0xE67A1104);
	writel(0x00002064, 0xE67A1108);
	writel(0x00002032, 0xE67A110C);
	writel(0x00001FB0, 0xE67A1110);
	writel(0x00000001, 0xE67A1114);
	writel(0x00002078, 0xE67A1118);
	writel(0x0000204B, 0xE67A111C);
	writel(0x0000201E, 0xE67A1120);
	writel(0x00000001, 0xE67A1128);
	writel(0x00000002, 0xE67A1200);
	writel(0x00002096, 0xE67A1204);
	writel(0x00002064, 0xE67A1208);
	writel(0x00002032, 0xE67A120C);
	writel(0x00001FB0, 0xE67A1210);
	writel(0x00000001, 0xE67A1214);
	writel(0x00002078, 0xE67A1218);
	writel(0x0000204B, 0xE67A121C);
	writel(0x0000201E, 0xE67A1220);
	writel(0x00000001, 0xE67A1228);
	writel(0x00000002, 0xE67A1300);
	writel(0x00002096, 0xE67A1304);
	writel(0x00002064, 0xE67A1308);
	writel(0x00002032, 0xE67A130C);
	writel(0x00001FB0, 0xE67A1310);
	writel(0x00000001, 0xE67A1314);
	writel(0x00002078, 0xE67A1318);
	writel(0x0000204B, 0xE67A131C);
	writel(0x0000201E, 0xE67A1320);
	writel(0x00000001, 0xE67A1328);
	writel(0x00000002, 0xE67A1400);
	writel(0x00002096, 0xE67A1404);
	writel(0x00002064, 0xE67A1408);
	writel(0x00002032, 0xE67A140C);
	writel(0x00001FB0, 0xE67A1410);
	writel(0x00000001, 0xE67A1414);
	writel(0x00002078, 0xE67A1418);
	writel(0x0000204B, 0xE67A141C);
	writel(0x0000201E, 0xE67A1420);
	writel(0x00000001, 0xE67A1428);
	writel(0x00000002, 0xE67A1500);
	writel(0x00002096, 0xE67A1504);
	writel(0x00002064, 0xE67A1508);
	writel(0x00002032, 0xE67A150C);
	writel(0x00001FB0, 0xE67A1510);
	writel(0x00000001, 0xE67A1514);
	writel(0x00002078, 0xE67A1518);
	writel(0x0000204B, 0xE67A151C);
	writel(0x0000201E, 0xE67A1520);
	writel(0x00000001, 0xE67A1528);
	writel(0x00000002, 0xE67A1600);
	writel(0x00002096, 0xE67A1604);
	writel(0x00002064, 0xE67A1608);
	writel(0x00002032, 0xE67A160C);
	writel(0x00001FB0, 0xE67A1610);
	writel(0x00000001, 0xE67A1614);
	writel(0x00002078, 0xE67A1618);
	writel(0x0000204B, 0xE67A161C);
	writel(0x0000201E, 0xE67A1620);
	writel(0x00000001, 0xE67A1628);
	writel(0x00000002, 0xE67A1700);
	writel(0x00002096, 0xE67A1704);
	writel(0x00002064, 0xE67A1708);
	writel(0x00002032, 0xE67A170C);
	writel(0x00001FB0, 0xE67A1710);
	writel(0x00000001, 0xE67A1714);
	writel(0x00002078, 0xE67A1718);
	writel(0x0000204B, 0xE67A171C);
	writel(0x0000201E, 0xE67A1720);
	writel(0x00000001, 0xE67A1728);
	writel(0x00000002, 0xE67A1800);
	writel(0x00002096, 0xE67A1804);
	writel(0x00002064, 0xE67A1808);
	writel(0x00002032, 0xE67A180C);
	writel(0x00001FB0, 0xE67A1810);
	writel(0x00000001, 0xE67A1814);
	writel(0x00002078, 0xE67A1818);
	writel(0x0000204B, 0xE67A181C);
	writel(0x0000201E, 0xE67A1820);
	writel(0x00000001, 0xE67A1828);
	writel(0x00000002, 0xE67A1900);
	writel(0x00002096, 0xE67A1904);
	writel(0x00002064, 0xE67A1908);
	writel(0x00002032, 0xE67A190C);
	writel(0x00001FB0, 0xE67A1910);
	writel(0x00000001, 0xE67A1914);
	writel(0x00002078, 0xE67A1918);
	writel(0x0000204B, 0xE67A191C);
	writel(0x0000201E, 0xE67A1920);
	writel(0x00000001, 0xE67A1928);
	writel(0x00000002, 0xE67A1A00);
	writel(0x00002096, 0xE67A1A04);
	writel(0x00002064, 0xE67A1A08);
	writel(0x00002032, 0xE67A1A0C);
	writel(0x00001FB0, 0xE67A1A10);
	writel(0x00000001, 0xE67A1A14);
	writel(0x00002078, 0xE67A1A18);
	writel(0x0000204B, 0xE67A1A1C);
	writel(0x0000201E, 0xE67A1A20);
	writel(0x00000001, 0xE67A1A28);
	writel(0x00000002, 0xE67A1B00);
	writel(0x00002096, 0xE67A1B04);
	writel(0x00002064, 0xE67A1B08);
	writel(0x00002032, 0xE67A1B0C);
	writel(0x00001FB0, 0xE67A1B10);
	writel(0x00000001, 0xE67A1B14);
	writel(0x00002078, 0xE67A1B18);
	writel(0x0000204B, 0xE67A1B1C);
	writel(0x0000201E, 0xE67A1B20);
	writel(0x00000001, 0xE67A1B28);
	writel(0x00000002, 0xE67A1C00);
	writel(0x00002096, 0xE67A1C04);
	writel(0x00002064, 0xE67A1C08);
	writel(0x00002032, 0xE67A1C0C);
	writel(0x00001FB0, 0xE67A1C10);
	writel(0x00000001, 0xE67A1C14);
	writel(0x00002078, 0xE67A1C18);
	writel(0x0000204B, 0xE67A1C1C);
	writel(0x0000201E, 0xE67A1C20);
	writel(0x00000001, 0xE67A1C28);
	writel(0x00000002, 0xE67A1D00);
	writel(0x00002096, 0xE67A1D04);
	writel(0x00002064, 0xE67A1D08);
	writel(0x00002032, 0xE67A1D0C);
	writel(0x00001FB0, 0xE67A1D10);
	writel(0x00000001, 0xE67A1D14);
	writel(0x00002078, 0xE67A1D18);
	writel(0x0000204B, 0xE67A1D1C);
	writel(0x0000201E, 0xE67A1D20);
	writel(0x00000001, 0xE67A1D28);
	writel(0x00000002, 0xE67A1E00);
	writel(0x00002096, 0xE67A1E04);
	writel(0x00002064, 0xE67A1E08);
	writel(0x00002032, 0xE67A1E0C);
	writel(0x00001FB0, 0xE67A1E10);
	writel(0x00000001, 0xE67A1E14);
	writel(0x00002078, 0xE67A1E18);
	writel(0x0000204B, 0xE67A1E1C);
	writel(0x0000201E, 0xE67A1E20);
	writel(0x00000001, 0xE67A1E28);
	writel(0x00000002, 0xE67A1F00);
	writel(0x00002096, 0xE67A1F04);
	writel(0x00002064, 0xE67A1F08);
	writel(0x00002032, 0xE67A1F0C);
	writel(0x00001FB0, 0xE67A1F10);
	writel(0x00000001, 0xE67A1F14);
	writel(0x00002078, 0xE67A1F18);
	writel(0x0000204B, 0xE67A1F1C);
	writel(0x0000201E, 0xE67A1F20);
	writel(0x00000001, 0xE67A1F28);

	/* DBSC1 - Write */
	writel(0x00000002, 0xE67A2000);
	writel(0x00002096, 0xE67A2004);
	writel(0x00002064, 0xE67A2008);
	writel(0x00002050, 0xE67A200C);
	writel(0x0000203A, 0xE67A2010);
	writel(0x00000001, 0xE67A2014);
	writel(0x00002078, 0xE67A2018);
	writel(0x0000204B, 0xE67A201C);
	writel(0x0000203C, 0xE67A2020);
	writel(0x00000001, 0xE67A2028);
	writel(0x00000002, 0xE67A2100);
	writel(0x00002096, 0xE67A2104);
	writel(0x00002064, 0xE67A2108);
	writel(0x00002050, 0xE67A210C);
	writel(0x0000203A, 0xE67A2110);
	writel(0x00000001, 0xE67A2114);
	writel(0x00002078, 0xE67A2118);
	writel(0x0000204B, 0xE67A211C);
	writel(0x0000203C, 0xE67A2120);
	writel(0x00000001, 0xE67A2128);
	writel(0x00000002, 0xE67A2200);
	writel(0x00002096, 0xE67A2204);
	writel(0x00002064, 0xE67A2208);
	writel(0x00002050, 0xE67A220C);
	writel(0x0000203A, 0xE67A2210);
	writel(0x00000001, 0xE67A2214);
	writel(0x00002078, 0xE67A2218);
	writel(0x0000204B, 0xE67A221C);
	writel(0x0000203C, 0xE67A2220);
	writel(0x00000001, 0xE67A2228);
	writel(0x00000002, 0xE67A2300);
	writel(0x00002096, 0xE67A2304);
	writel(0x00002064, 0xE67A2308);
	writel(0x00002050, 0xE67A230C);
	writel(0x0000203A, 0xE67A2310);
	writel(0x00000001, 0xE67A2314);
	writel(0x00002078, 0xE67A2318);
	writel(0x0000204B, 0xE67A231C);
	writel(0x0000203C, 0xE67A2320);
	writel(0x00000001, 0xE67A2328);
	writel(0x00000002, 0xE67A2400);
	writel(0x00002096, 0xE67A2404);
	writel(0x00002064, 0xE67A2408);
	writel(0x00002050, 0xE67A240C);
	writel(0x0000203A, 0xE67A2410);
	writel(0x00000001, 0xE67A2414);
	writel(0x00002078, 0xE67A2418);
	writel(0x0000204B, 0xE67A241C);
	writel(0x0000203C, 0xE67A2420);
	writel(0x00000001, 0xE67A2428);
	writel(0x00000002, 0xE67A2500);
	writel(0x00002096, 0xE67A2504);
	writel(0x00002064, 0xE67A2508);
	writel(0x00002050, 0xE67A250C);
	writel(0x0000203A, 0xE67A2510);
	writel(0x00000001, 0xE67A2514);
	writel(0x00002078, 0xE67A2518);
	writel(0x0000204B, 0xE67A251C);
	writel(0x0000203C, 0xE67A2520);
	writel(0x00000001, 0xE67A2528);
	writel(0x00000002, 0xE67A2600);
	writel(0x00002096, 0xE67A2604);
	writel(0x00002064, 0xE67A2608);
	writel(0x00002050, 0xE67A260C);
	writel(0x0000203A, 0xE67A2610);
	writel(0x00000001, 0xE67A2614);
	writel(0x00002078, 0xE67A2618);
	writel(0x0000204B, 0xE67A261C);
	writel(0x0000203C, 0xE67A2620);
	writel(0x00000001, 0xE67A2628);
	writel(0x00000002, 0xE67A2700);
	writel(0x00002096, 0xE67A2704);
	writel(0x00002064, 0xE67A2708);
	writel(0x00002050, 0xE67A270C);
	writel(0x0000203A, 0xE67A2710);
	writel(0x00000001, 0xE67A2714);
	writel(0x00002078, 0xE67A2718);
	writel(0x0000204B, 0xE67A271C);
	writel(0x0000203C, 0xE67A2720);
	writel(0x00000001, 0xE67A2728);
	writel(0x00000002, 0xE67A2800);
	writel(0x00002096, 0xE67A2804);
	writel(0x00002064, 0xE67A2808);
	writel(0x00002050, 0xE67A280C);
	writel(0x0000203A, 0xE67A2810);
	writel(0x00000001, 0xE67A2814);
	writel(0x00002078, 0xE67A2818);
	writel(0x0000204B, 0xE67A281C);
	writel(0x0000203C, 0xE67A2820);
	writel(0x00000001, 0xE67A2828);
	writel(0x00000002, 0xE67A2900);
	writel(0x00002096, 0xE67A2904);
	writel(0x00002064, 0xE67A2908);
	writel(0x00002050, 0xE67A290C);
	writel(0x0000203A, 0xE67A2910);
	writel(0x00000001, 0xE67A2914);
	writel(0x00002078, 0xE67A2918);
	writel(0x0000204B, 0xE67A291C);
	writel(0x0000203C, 0xE67A2920);
	writel(0x00000001, 0xE67A2928);
	writel(0x00000002, 0xE67A2A00);
	writel(0x00002096, 0xE67A2A04);
	writel(0x00002064, 0xE67A2A08);
	writel(0x00002050, 0xE67A2A0C);
	writel(0x0000203A, 0xE67A2A10);
	writel(0x00000001, 0xE67A2A14);
	writel(0x00002078, 0xE67A2A18);
	writel(0x0000204B, 0xE67A2A1C);
	writel(0x0000203C, 0xE67A2A20);
	writel(0x00000001, 0xE67A2A28);
	writel(0x00000002, 0xE67A2B00);
	writel(0x00002096, 0xE67A2B04);
	writel(0x00002064, 0xE67A2B08);
	writel(0x00002050, 0xE67A2B0C);
	writel(0x0000203A, 0xE67A2B10);
	writel(0x00000001, 0xE67A2B14);
	writel(0x00002078, 0xE67A2B18);
	writel(0x0000204B, 0xE67A2B1C);
	writel(0x0000203C, 0xE67A2B20);
	writel(0x00000001, 0xE67A2B28);
	writel(0x00000002, 0xE67A2C00);
	writel(0x00002096, 0xE67A2C04);
	writel(0x00002064, 0xE67A2C08);
	writel(0x00002050, 0xE67A2C0C);
	writel(0x0000203A, 0xE67A2C10);
	writel(0x00000001, 0xE67A2C14);
	writel(0x00002078, 0xE67A2C18);
	writel(0x0000204B, 0xE67A2C1C);
	writel(0x0000203C, 0xE67A2C20);
	writel(0x00000001, 0xE67A2C28);
	writel(0x00000002, 0xE67A2D00);
	writel(0x00002096, 0xE67A2D04);
	writel(0x00002064, 0xE67A2D08);
	writel(0x00002050, 0xE67A2D0C);
	writel(0x0000203A, 0xE67A2D10);
	writel(0x00000001, 0xE67A2D14);
	writel(0x00002078, 0xE67A2D18);
	writel(0x0000204B, 0xE67A2D1C);
	writel(0x0000203C, 0xE67A2D20);
	writel(0x00000001, 0xE67A2D28);
	writel(0x00000002, 0xE67A2E00);
	writel(0x00002096, 0xE67A2E04);
	writel(0x00002064, 0xE67A2E08);
	writel(0x00002050, 0xE67A2E0C);
	writel(0x0000203A, 0xE67A2E10);
	writel(0x00000001, 0xE67A2E14);
	writel(0x00002078, 0xE67A2E18);
	writel(0x0000204B, 0xE67A2E1C);
	writel(0x0000203C, 0xE67A2E20);
	writel(0x00000001, 0xE67A2E28);
	writel(0x00000002, 0xE67A2F00);
	writel(0x00002096, 0xE67A2F04);
	writel(0x00002064, 0xE67A2F08);
	writel(0x00002050, 0xE67A2F0C);
	writel(0x0000203A, 0xE67A2F10);
	writel(0x00000001, 0xE67A2F14);
	writel(0x00002078, 0xE67A2F18);
	writel(0x0000204B, 0xE67A2F1C);
	writel(0x0000203C, 0xE67A2F20);
	writel(0x00000001, 0xE67A2F28);
}

void __init  qos_init_es2(void)
{
	struct r8a7791_s3c *s3c;
	struct r8a7791_s3c_qos *s3c_qos;
	struct r8a7791_mxi *mxi;
	struct r8a7791_mxi_qos *mxi_qos;
	struct r8a7791_axi_qos *axi_qos;

#if 0
	/* DBSC DBADJ2 */
	writel(0x20042004, DBSC3_0_DBADJ2);
	writel(0x20042004, DBSC3_1_DBADJ2);
#endif
	/* S3C -QoS */
	s3c = (struct r8a7791_s3c *)S3C_BASE;
	writel(0x00FF1B0C, &s3c->s3cadsplcr);
	writel(0x1F0D0B0A, &s3c->s3crorr);
	writel(0x1F0D0B09, &s3c->s3cworr);
	writel(0x00200808, &s3c->s3carcr11);

	/* QoS Control Registers */
	s3c_qos = (struct r8a7791_s3c_qos *)S3C_QOS_CCI0_BASE;
	writel(0x00890089, &s3c_qos->s3cqos0);
	writel(0x20960010, &s3c_qos->s3cqos1);
	writel(0x20302030, &s3c_qos->s3cqos2);
	writel(0x20AA2200, &s3c_qos->s3cqos3);
	writel(0x00002032, &s3c_qos->s3cqos4);
	writel(0x20960010, &s3c_qos->s3cqos5);
	writel(0x20302030, &s3c_qos->s3cqos6);
	writel(0x20AA2200, &s3c_qos->s3cqos7);
	writel(0x00002032, &s3c_qos->s3cqos8);

	s3c_qos = (struct r8a7791_s3c_qos *)S3C_QOS_CCI1_BASE;
	writel(0x00890089, &s3c_qos->s3cqos0);
	writel(0x20960010, &s3c_qos->s3cqos1);
	writel(0x20302030, &s3c_qos->s3cqos2);
	writel(0x20AA2200, &s3c_qos->s3cqos3);
	writel(0x00002032, &s3c_qos->s3cqos4);
	writel(0x20960010, &s3c_qos->s3cqos5);
	writel(0x20302030, &s3c_qos->s3cqos6);
	writel(0x20AA2200, &s3c_qos->s3cqos7);
	writel(0x00002032, &s3c_qos->s3cqos8);

	s3c_qos = (struct r8a7791_s3c_qos *)S3C_QOS_MXI_BASE;
	writel(0x80928092, &s3c_qos->s3cqos0);
	writel(0x20960020, &s3c_qos->s3cqos1);
	writel(0x20302030, &s3c_qos->s3cqos2);
	writel(0x20AA20DC, &s3c_qos->s3cqos3);
	writel(0x00002032, &s3c_qos->s3cqos4);
	writel(0x20960020, &s3c_qos->s3cqos5);
	writel(0x20302030, &s3c_qos->s3cqos6);
	writel(0x20AA20DC, &s3c_qos->s3cqos7);
	writel(0x00002032, &s3c_qos->s3cqos8);

	s3c_qos = (struct r8a7791_s3c_qos *)S3C_QOS_AXI_BASE;
	writel(0x00820082, &s3c_qos->s3cqos0);
	writel(0x20960020, &s3c_qos->s3cqos1);
	writel(0x20302030, &s3c_qos->s3cqos2);
	writel(0x20AA20FA, &s3c_qos->s3cqos3);
	writel(0x00002032, &s3c_qos->s3cqos4);
	writel(0x20960020, &s3c_qos->s3cqos5);
	writel(0x20302030, &s3c_qos->s3cqos6);
	writel(0x20AA20FA, &s3c_qos->s3cqos7);
	writel(0x00002032, &s3c_qos->s3cqos8);
#if 0
	/* DBSC -QoS */
	/* DBSC0 - Read */
	for (i = DBSC3_00; i < DBSC3_NR; i++) {
		qos_addr = (struct r8a7791_dbsc3_qos *)dbsc3_0_r_qos_addr[i];
		writel(0x00000002, &qos_addr->dblgcnt);
		writel(0x00002096, &qos_addr->dbtmval0);
		writel(0x00002064, &qos_addr->dbtmval1);
		writel(0x00002032, &qos_addr->dbtmval2);
		writel(0x00001FB0, &qos_addr->dbtmval3);
		writel(0x00000001, &qos_addr->dbrqctr);
		writel(0x00002078, &qos_addr->dbthres0);
		writel(0x0000204B, &qos_addr->dbthres1);
		writel(0x0000201E, &qos_addr->dbthres2);
		writel(0x00000001, &qos_addr->dblgqon);
	}

	/* DBSC0 - Write */
	for (i = DBSC3_00; i < DBSC3_NR; i++) {
		qos_addr = (struct r8a7791_dbsc3_qos *)dbsc3_0_w_qos_addr[i];
		writel(0x00000002, &qos_addr->dblgcnt);
		writel(0x00002096, &qos_addr->dbtmval0);
		writel(0x00002064, &qos_addr->dbtmval1);
		writel(0x00002050, &qos_addr->dbtmval2);
		writel(0x0000203A, &qos_addr->dbtmval3);
		writel(0x00000001, &qos_addr->dbrqctr);
		writel(0x00002078, &qos_addr->dbthres0);
		writel(0x0000204B, &qos_addr->dbthres1);
		writel(0x0000203C, &qos_addr->dbthres2);
		writel(0x00000001, &qos_addr->dblgqon);
	}

	/* DBSC1 - Read */
	for (i = DBSC3_00; i < DBSC3_NR; i++) {
		qos_addr = (struct r8a7791_dbsc3_qos *)dbsc3_1_r_qos_addr[i];
		writel(0x00000002, &qos_addr->dblgcnt);
		writel(0x00002096, &qos_addr->dbtmval0);
		writel(0x00002064, &qos_addr->dbtmval1);
		writel(0x00002032, &qos_addr->dbtmval2);
		writel(0x00001FB0, &qos_addr->dbtmval3);
		writel(0x00000001, &qos_addr->dbrqctr);
		writel(0x00002078, &qos_addr->dbthres0);
		writel(0x0000204B, &qos_addr->dbthres1);
		writel(0x0000201E, &qos_addr->dbthres2);
		writel(0x00000001, &qos_addr->dblgqon);
	}

	/* DBSC1 - Write */
	for (i = DBSC3_00; i < DBSC3_NR; i++) {
		qos_addr = (struct r8a7791_dbsc3_qos *)dbsc3_1_w_qos_addr[i];
		writel(0x00000002, &qos_addr->dblgcnt);
		writel(0x00002096, &qos_addr->dbtmval0);
		writel(0x00002064, &qos_addr->dbtmval1);
		writel(0x00002050, &qos_addr->dbtmval2);
		writel(0x0000203A, &qos_addr->dbtmval3);
		writel(0x00000001, &qos_addr->dbrqctr);
		writel(0x00002078, &qos_addr->dbthres0);
		writel(0x0000204B, &qos_addr->dbthres1);
		writel(0x0000203C, &qos_addr->dbthres2);
		writel(0x00000001, &qos_addr->dblgqon);
	}
#endif
	/* CCI-400 -QoS */
	writel(0x20001000, CCI_400_MAXOT_1);
	writel(0x20001000, CCI_400_MAXOT_2);
	writel(0x0000000C, CCI_400_QOSCNTL_1);
	writel(0x0000000C, CCI_400_QOSCNTL_2);

	/* MXI -QoS */
	/* Transaction Control (MXI) */
	mxi = (struct r8a7791_mxi *)MXI_BASE;
	writel(0x00000013, &mxi->mxrtcr);
	writel(0x00000013, &mxi->mxwtcr);
	writel(0x00780080, &mxi->mxsaar0);
	writel(0x02000800, &mxi->mxsaar1);

	/* QoS Control (MXI) */
	mxi_qos = (struct r8a7791_mxi_qos *)MXI_QOS_BASE;
	writel(0x0000000C, &mxi_qos->vspdu0);
	writel(0x0000000C, &mxi_qos->vspdu1);
	writel(0x0000000E, &mxi_qos->du0);

	/* AXI -QoS */
	/* Transaction Control (MXI) */
	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SYX64TO128_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_AVB_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_G2D_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_IMP0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002021, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_IMP1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002037, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_IMUX0_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_IMUX1_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_IMUX2_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_LBS_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000214C, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MMUDS_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MMUM_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MMUR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MMUS0_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MMUS1_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MTSB0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002021, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MTSB1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002021, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_PCI_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000214C, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_RTX_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SDS0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SDS1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_USB20_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_USB21_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_USB22_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_USB30_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000214C, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_AX2M_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_CC50_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002029, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_CCI_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_CS_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_DDM_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_ETH_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_MPXM_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SAT0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SAT1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SDM0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000214C, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_SDM1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000214C, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_TRAB_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x000020A6, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_UDM0_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI_UDM1_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	/* QoS Register (RT-AXI) */
	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_SHX_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_DBG_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_RDM_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002299, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_RDS_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002029, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_RTX64TO128_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_STPRO_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002029, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)RT_AXI_SY2RT_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	/* QoS Register (MP-AXI) */
	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_ADSP_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002037, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_ASDS0_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002014, &axi_qos->qosctset0);
	writel(0x00000040, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_ASDS1_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002014, &axi_qos->qosctset0);
	writel(0x00000040, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_MLP_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00001FF0, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00002001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_MMUMP_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_SPU_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x00002053, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MP_AXI_SPUC_BASE;
	writel(0x00000000, &axi_qos->qosconf);
	writel(0x0000206E, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	/* QoS Register (SYS-AXI256) */
	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI256_AXI128TO256_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020EB, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI256_SYX_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020EB, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI256_MPX_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020EB, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)SYS_AXI256_MXI_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020EB, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	/* QoS Register (CCI-AXI) */
	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUS0_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_SYX2_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUDS_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUM_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MXI_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x00002245, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUS1_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)CCI_AXI_MMUMP_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002004, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000000, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	/* QoS Register (Media-AXI) */
	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_MXR_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020DC, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x000020AA, &axi_qos->qosthres0);
	writel(0x00002032, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_MXW_BASE;
	writel(0x00000002, &axi_qos->qosconf);
	writel(0x000020DC, &axi_qos->qosctset0);
	writel(0x00002096, &axi_qos->qosctset1);
	writel(0x00002030, &axi_qos->qosctset2);
	writel(0x00002030, &axi_qos->qosctset3);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x000020AA, &axi_qos->qosthres0);
	writel(0x00002032, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_JPR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_JPW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_TDMR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_TDMW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSP1CR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSP1CW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPDU0CR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPDU0CW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPDU1CR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPDU1CW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002190, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VIN0W_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00001FF0, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00002001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_FDP0R_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_FDP0W_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_IMSR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_IMSW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSP1R_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSP1W_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_FDP1R_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_FDP1W_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_IMRR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_IMRW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPD0R_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPD0W_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPD1R_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VSPD1W_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x000020C8, &axi_qos->qosctset0);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_DU0R_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x00002063, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_DU0W_BASE;
	writel(0x00000003, &axi_qos->qosconf);
	writel(0x00002063, &axi_qos->qosctset0);
	writel(0x00000001, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VCP0CR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002073, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VCP0CW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002073, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VCP0VR_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002073, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VCP0VW_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002073, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00000001, &axi_qos->qosthres0);
	writel(0x00000001, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);

	axi_qos = (struct r8a7791_axi_qos *)MEDIA_AXI_VPC0R_BASE;
	writel(0x00000001, &axi_qos->qosconf);
	writel(0x00002073, &axi_qos->qosctset0);
	writel(0x00000020, &axi_qos->qosreqctr);
	writel(0x00002064, &axi_qos->qosthres0);
	writel(0x00002004, &axi_qos->qosthres1);
	writel(0x00000001, &axi_qos->qosthres2);
	writel(0x00000001, &axi_qos->qosqon);
}

void __init qos_init(void)
{
	qos_dbsc_init_es2();
	qos_init_es2();
}
